@@ -324,7 +324,7 @@ class coinhe(Exchange):
     #
     #     return result
 
-    def cancel_all_order(self, symbol=None, params={}):
+    def cancel_all_orders(self, symbol=None, params={}):
         # self.load_markets()
         # market = self.market(symbol)
 
